@@ -38,16 +38,15 @@ class Linf1:
                  [default: gamma=1]
     """
 
-    def __init__(self, gamma: Union[float, np.ndarray] = 1):
-        if np.any(gamma <= 0):
-            raise Exception(
-                "'gamma' (or all of its components if it is an array)" +
-                " must be strictly positive"
-            )
-        self.gamma = gamma
+    def __init__(self):
+        pass
 
-    def prox(self, x: np.ndarray) -> np.ndarray:
-        return Linf(gamma=self.gamma, axis=1).prox(x)
+    def prox(
+            self,
+            x: np.ndarray,
+            gamma: Union[float, np.ndarray] = 1.0
+    ) -> np.ndarray:
+        return Linf(axis=1).prox(x, gamma)
 
     def __call__(self, x: np.ndarray) -> float:
-        return Linf(gamma=self.gamma, axis=1)(x)
+        return Linf(axis=1)(x)
