@@ -36,19 +36,18 @@ class Rank:
     ========
      x         -  (M,N) -array_like ( representing an M*N matrix )
      gamma     - positive, scalar or ND array compatible with the size of 'x'
-                 [default: gamma=1]
+                 [default: gamma=1.0]
     """
 
-    def __init__(self, gamma: Union[float, np.ndarray] = 1):
-        if np.any(gamma <= 0):
-            raise ValueError(
-                "'gamma' (or all of its components if it is an array)" +
-                " must be strictly positive"
-            )
-        self.gamma = gamma
+    def __init__(self):
+        pass
 
-    def prox(self, x: np.ndarray) -> np.ndarray:
-        return prox_svd(x, 1, L0Norm(gamma=self.gamma).prox)
+    def prox(
+            self,
+            x: np.ndarray,
+            gamma: Union[float, np.ndarray] = 1.0
+    ) -> np.ndarray:
+        return prox_svd(x, gamma, L0Norm().prox)
 
     def __call__(self, x: np.ndarray) -> np.float:
-        return fun_svd(x, 1, L0Norm(gamma=self.gamma))
+        return fun_svd(x, 1, L0Norm())
